@@ -1,8 +1,7 @@
 package # Hide from PAUSE
     TestApp::View::Email::Template::AppConfig;
-our $VERSION = '0.21_01';
 
-use Email::Sender::Simple;
+use Email::Send::Test;
 
 use base 'Catalyst::View::Email::Template';
 
